"""Common configuration constants
"""

PROJECTNAME = 'redturtle.video'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'RTRemoteVideo': 'redturtle.video: Add RTRemoteVideo',
    'RTInternalVideo': 'redturtle.video: Add RTInternalVideo',
}
