/*
 * Rules for displaying a Play button on RT videos
 */

.videoWrapper {
    position: relative;
    display: block;
    /* z-index: 100; */
}

.iconPlay {
    position:absolute;
    background: transparent url(++resource++fpPlayButtonBig.png) no-repeat center center;
    width: 83px;
    height: 83px;
    display: block;
    top: 50%;
    left: 50%;
    /* z-index: 102; */
}

